versioncheck

package
v0.9.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: AGPL-3.0, AGPL-3.0-or-later, AGPL-3.0, + 1 more Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BackgroundCheck

func BackgroundCheck(currentVersion string) <-chan string

BackgroundCheck starts an async version check and returns a channel that receives the latest version string if one newer than currentVersion is available. The channel receives "" if no update is found or on any error. The check uses a 10-minute on-disk cache so it rarely hits the network.

Types

This section is empty.

Jump to