Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BackgroundCheck ¶
BackgroundCheck starts an async version check and returns a channel that receives the latest version string if one newer than currentVersion is available. The channel receives "" if no update is found or on any error. The check uses a 10-minute on-disk cache so it rarely hits the network.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.